@@ -1,33 +1,6 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
-#
-#############################################################################
-##
-## Copyright (C) 2016 The Qt Company Ltd.
-## Contact: https://www.qt.io/licensing/
-##
-## This file is part of the test suite of Qt for Python.
-##
-## $QT_BEGIN_LICENSE:GPL-EXCEPT$
-## Commercial License Usage
-## Licensees holding valid commercial Qt licenses may use this file in
-## accordance with the commercial license agreement provided with the
-## Software or, alternatively, in accordance with the terms contained in
-## a written agreement between you and The Qt Company. For licensing terms
-## and conditions see https://www.qt.io/terms-conditions. For further
-## information use the contact form at https://www.qt.io/contact-us.
-##
-## GNU General Public License Usage
-## Alternatively, this file may be used under the terms of the GNU
-## General Public License version 3 as published by the Free Software
-## Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
-## included in the packaging of this file. Please review the following
-## information to ensure the GNU General Public License requirements will
-## be met: https://www.gnu.org/licenses/gpl-3.0.html.
-##
-## $QT_END_LICENSE$
-##
-#############################################################################
+# Copyright (C) 2022 The Qt Company Ltd.
+# SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 '''Tests various usages of the type converters.'''
 
@@ -203,14 +176,6 @@ class PrimitiveConversionTest(unittest.TestCase):
         point.setX(large_int)
         self.assertEqual(round(point.x()), large_int)
 
-    def testUnsignedLongLongAsFloat(self):
-        """PYSIDE-2652: When passing an unsigned long long to a function taking float,
-           an unsigned 64bit conversion should be done."""
-        point = sample.PointF(1, 2)
-        large_int = 2**63
-        point.setX(large_int)
-        self.assertEqual(round(point.x()), large_int)
-
 
 if __name__ == '__main__':
     unittest.main()
